pub unsafe trait LimitParam { }Expand description
Safety
This trait cannot be implemented outside of this module.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub unsafe trait LimitParam { }This trait cannot be implemented outside of this module.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".