pub unsafe trait NonUnwinding: Allocator { }Expand description
Safety
Allocator implementing this trait should not panic with stack unwinding.
This means, either it should not initiate panic directly or indirectly,
either it should be strongly linked
with the standard unstable panic_abort crate.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".